"""
openedx_events Django application initialization.
"""

from django.apps import AppConfig


class OpenedxEventsConfig(AppConfig):
    """
    Configuration for the openedx_events Django application.
    """

    name = 'openedx_events'
